import React, { useEffect } from "react";
import Navbar from "./components/Navbar";
import "./App.css";
import { BrowserRouter as Router, Switch, Route } from "react-router-dom";
import Home from "./components/pages/Home";
import Ueber from "./components/pages/Ueber";
import Lizenzen from "./components/pages/lizenzen";
import Privacy from "./components/pages/Privacy";
import Login from "./components/pages/Login";
import Register from "./components/pages/Register";
import Manual from "./components/pages/Manual";
import Secret from "./components/pages/Secret";
import Umfrage from "./components/pages/Umfrage";
import PrivateRoute from "./auth/PrivateRoute";
import { Logger } from "@behametrics/logger-web";
import { useAuth } from "./auth/AuthProvider";

function App() {
  let logger = new Logger({
    //inputs: ["cursor", "wheel", "keyboard", "touch"],
    inputs: ["keyboard"],
    logToConsole: true,
  });
  logger.init();

  let [isLoggedIn] = useAuth();

  useEffect(() => {
    document.title = `${isLoggedIn}`;
    console.log(isLoggedIn);
    if (isLoggedIn === false) {
      logger.stop();
      console.log("stopped logger");
    } else {
      logger.start();
      console.log("start logger");
    }
  });

  return (
    <>
      <Router>
        <Navbar />
        <Switch>
          <Route path="/" exact component={Home} />
          <Route path="/services" component={Ueber} />
          <Route path="/lizenzen" component={Lizenzen} />
          <Route path="/privacy" component={Privacy} />
          <Route path="/login" component={Login} />
          <Route path="/register" component={Register} />
          <Route path="/manual" component={Manual} />
          <Route path="/ueber" component={Ueber} />
          <PrivateRoute path="/secret" component={Secret} />
          <PrivateRoute path="/umfrage" component={Umfrage} />
        </Switch>
      </Router>
    </>
  );
}

export default App;
